Django Replay
=============

Django Replay is an Apache2 licensed Python module that records and
replays web requests.

Features
--------

- Pure-Python
- Developed on Python 2.7
- Tested on CPython 2.7

Quickstart
----------

Installing Django Replay is simple with
`pip <http://www.pip-installer.org/>`_::

  $ pip install django-replay

.. todo:: Describe django app installation steps.

Tutorial
--------

.. todo:: Describe workflow.

Reference and Indices
---------------------

.. toctree::

   api

* `Django Replay Documentation`_
* `Django Replay at PyPI`_
* `Django Replay at GitHub`_
* `Django Replay Issue Tracker`_
* :ref:`search`
* :ref:`genindex`

.. _`Django Replay Documentation`: http://www.grantjenks.com/docs/django-replay/
.. _`Django Replay at PyPI`: https://pypi.python.org/pypi/django-replay/
.. _`Django Replay at GitHub`: https://github.com/grantjenks/django-replay/
.. _`Django Replay Issue Tracker`: https://github.com/grantjenks/django-replay/issues/

License
-------

.. include:: ../LICENSE
